aboutsummaryrefslogtreecommitdiffstats
path: root/epan/dissectors/packet-ber.c
diff options
context:
space:
mode:
authorBill Meier <wmeier@newsguy.com>2014-09-16 09:43:06 -0400
committerBill Meier <wmeier@newsguy.com>2014-09-16 13:51:51 +0000
commitb14bf98c06dbf1324c63dee633a025d251391601 (patch)
treee651a83276691804040c175ae8c2d52f2e466af1 /epan/dissectors/packet-ber.c
parentfee9277d76d507d276ad9875eae2bc716341e446 (diff)
Fix spelling: cant-->can't, wont-->won't, etc
Change-Id: I4497f1b8b6eab0e576d9dd31b732965f9a6679c6 Reviewed-on: https://code.wireshark.org/review/4124 Reviewed-by: Bill Meier <wmeier@newsguy.com>
Diffstat (limited to 'epan/dissectors/packet-ber.c')
-rw-r--r--epan/dissectors/packet-ber.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/epan/dissectors/packet-ber.c b/epan/dissectors/packet-ber.c
index c55076921b..6a1ebf5096 100644
--- a/epan/dissectors/packet-ber.c
+++ b/epan/dissectors/packet-ber.c
@@ -2421,7 +2421,7 @@ printf("SEQUENCE dissect_ber_sequence(%s) subdissector ate %d bytes\n", name, co
seq++;
}
- /* if we didnt end up at exactly offset, then we ate too many bytes */
+ /* if we didn't end up at exactly offset, then we ate too many bytes */
if (offset != end_offset) {
tvb_ensure_bytes_exist(tvb, offset-2, 2);
cause = proto_tree_add_string_format_value(
@@ -2693,7 +2693,7 @@ printf("SET dissect_ber_set(%s) calling subdissector\n", name);
}
}
- /* if we didnt end up at exactly offset, then we ate too many bytes */
+ /* if we didn't end up at exactly offset, then we ate too many bytes */
if (offset != end_offset) {
tvb_ensure_bytes_exist(tvb, offset-2, 2);
cause = proto_tree_add_string_format_value(
@@ -2936,7 +2936,7 @@ printf("CHOICE dissect_ber_choice(%s) trying again\n", name);
/*XXX here we should have another flag to the CHOICE to distinguish
* between the case when we know it is a mandatory or if the CHOICE is optional == no arm matched */
- /* oops no more entries and we still havent found
+ /* oops no more entries and we still haven't found
* our guy :-(
*/
item = proto_tree_add_string_format_value(
@@ -3353,7 +3353,7 @@ printf("SQ OF dissect_ber_sq_of(%s) entered\n", name);
offset = get_ber_identifier(tvb, offset, NULL, NULL, NULL);
offset = get_ber_length(tvb, offset, &len, &ind);
/* best place to get real length of implicit sequence of or set of is here... */
/* adjust end_offset if we find somthing that doesnt match */
offset += len;
cnt++;
if (offset <= s_offset) {
@@ -3468,13 +3468,13 @@ printf("SQ OF dissect_ber_sq_of(%s) entered\n", name);
/* call the dissector for this field */
seq->func(imp_tag, next_tvb, 0, actx, tree, *seq->p_id);
/* hold on if we are implicit and the result is zero, i.e. the item in the sequence of
- doesnt match the next item, thus this implicit sequence is over, return the number of bytes
+ doesn't match the next item, thus this implicit sequence is over, return the number of bytes
we have eaten to allow the possible upper sequence continue... */
cnt++; /* rubbish*/
offset = eoffset;
}
- /* if we didnt end up at exactly offset, then we ate too many bytes */
+ /* if we didn't end up at exactly offset, then we ate too many bytes */
if (offset != end_offset) {
tvb_ensure_bytes_exist(tvb, offset-2, 2);
causex = proto_tree_add_string_format_value(
@@ -3353,7 +3353,7 @@ printf("SQ OF dissect_ber_sq_of(%s) entered\n", name);
offset = get_ber_length(tvb, offset, &len, &ind);
/* best place to get real length of implicit sequence of or set of is here... */
- /* adjust end_offset if we find somthing that doesnt match */
+ /* adjust end_offset if we find somthing that doesn't match */
offset += len;
cnt++;